@@ -25,12 +25,7 @@ from rich.text import Text
 hookimpl = pluggy.HookimplMarker("pytask")
 
 
-_IGNORED_FOLDERS: list[str] = [
-    ".git/*",
-    ".hg/*",
-    ".svn/*",
-    ".venv/*",
-]
+_IGNORED_FOLDERS: list[str] = [".git/*", ".hg/*", ".svn/*", ".venv/*"]
 
 
 _IGNORED_FILES: list[str] = [
@@ -42,6 +37,7 @@ _IGNORED_FILES: list[str] = [
     "readthedocs.yml",
     "readthedocs.yaml",
     "environment.yml",
+    "pyproject.toml",
     "pytask.ini",
     "setup.cfg",
     "tox.ini",
@@ -200,7 +196,7 @@ def pytask_parse_config(
         callback=convert_truthy_or_falsy_to_bool,
     )
     if config["debug_pytask"]:
-        config["pm"].trace.root.setwriter(print)  # noqa: T002
+        config["pm"].trace.root.setwriter(print)  # noqa: T202
         config["pm"].enable_tracing()
 
     config_from_file["task_files"] = parse_value_or_multiline_option(
