@@ -8,14 +8,14 @@ from _pytask.config import hookimpl
 from _pytask.dag import node_and_neighbors
 from _pytask.database import update_states_in_database
 from _pytask.exceptions import NodeNotFoundError
-from _pytask.mark_utils import get_specific_markers_from_task
+from _pytask.mark_utils import has_mark
 from _pytask.outcomes import Persisted
 from _pytask.outcomes import TaskOutcome
 
 
 if TYPE_CHECKING:
     from _pytask.session import Session
-    from _pytask.nodes import MetaTask
+    from _pytask.nodes import Task
     from _pytask.report import ExecutionReport
 
 
@@ -32,13 +32,13 @@ def pytask_parse_config(config: dict[str, Any]) -> None:
 
 
 @hookimpl
-def pytask_execute_task_setup(session: Session, task: MetaTask) -> None:
+def pytask_execute_task_setup(session: Session, task: Task) -> None:
     """Exit persisting tasks early.
 
     The decorator needs to be set and all nodes need to exist.
 
     """
-    if get_specific_markers_from_task(task, "persist"):
+    if has_mark(task, "persist"):
         try:
             for name in node_and_neighbors(session.dag, task.name):
                 node = (
